@@ -1,5 +1,6 @@
 import asyncio
 import inspect
+import logging
 import typing
 from functools import wraps
 
@@ -20,6 +21,8 @@ if typing.TYPE_CHECKING:
 
 __all__ = ["Route", "WebSocketRoute", "Router"]
 
+logger = logging.getLogger(__name__)
+
 
 FieldsMap = typing.Dict[str, Field]
 MethodsMap = typing.Dict[str, FieldsMap]
@@ -164,20 +167,24 @@ class Route(starlette.routing.Route, FieldsMixin):
                 "request": http.Request(scope, receive),
             }
 
-            injected_func = await app.injector.inject(endpoint, state)
+            try:
+                injected_func = await app.injector.inject(endpoint, state)
 
-            if asyncio.iscoroutinefunction(endpoint):
-                response = await injected_func()
-            else:
-                response = await run_in_threadpool(injected_func)
+                if asyncio.iscoroutinefunction(endpoint):
+                    response = await injected_func()
+                else:
+                    response = await run_in_threadpool(injected_func)
 
-            # Wrap response data with a proper response class
-            if isinstance(response, (dict, list)):
-                response = APIResponse(content=response, schema=get_output_schema(endpoint))
-            elif isinstance(response, str):
-                response = APIResponse(content=response)
-            elif response is None:
-                response = APIResponse(content="")
+                # Wrap response data with a proper response class
+                if isinstance(response, (dict, list)):
+                    response = APIResponse(content=response, schema=get_output_schema(endpoint))
+                elif isinstance(response, str):
+                    response = APIResponse(content=response)
+                elif response is None:
+                    response = APIResponse(content="")
+            except Exception:
+                logger.exception("Error building response")
+                raise
 
             await response(scope, receive, send)
 
@@ -216,10 +223,14 @@ class WebSocketRoute(starlette.routing.WebSocketRoute, FieldsMixin):
                 "websocket": websockets.WebSocket(scope, receive, send),
             }
 
-            injected_func = await app.injector.inject(endpoint, state)
+            try:
+                injected_func = await app.injector.inject(endpoint, state)
 
-            kwargs = scope.get("kwargs", {})
-            await injected_func(**kwargs)
+                kwargs = scope.get("kwargs", {})
+                await injected_func(**kwargs)
+            except Exception:
+                logger.exception("Error building response")
+                raise
 
         return _app
 
@@ -289,21 +300,24 @@ class Router(starlette.routing.Router):
 
         return decorator
 
-    def get_route_from_scope(self, scope) -> typing.Tuple[Route, typing.Optional[typing.Dict]]:
+    def get_route_from_scope(self, scope, mounted=False) -> typing.Tuple[Route, typing.Optional[typing.Dict]]:
         partial = None
 
         for route in self.routes:
             if isinstance(route, Mount):
                 path = scope.get("path", "")
                 root_path = scope.pop("root_path", "")
-                scope["path"] = root_path + path
+                if not mounted:
+                    scope["path"] = root_path + path
 
             match, child_scope = route.matches(scope)
             if match == Match.FULL:
                 scope.update(child_scope)
 
                 if isinstance(route, Mount):
-                    route, mount_scope = route.app.get_route_from_scope(scope)
+                    if mounted:
+                        scope["root_path"] = root_path + child_scope.get("root_path", "")
+                    route, mount_scope = route.app.get_route_from_scope(scope, mounted=True)
                     return route, mount_scope
 
                 return route, scope
